@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-from enum import StrEnum
+from enum import StrEnum, auto
 from typing import Optional
 import logging
 
@@ -7,7 +7,12 @@ import typer
 
 from .lib import GitBlog
 
-LogLevel = StrEnum("LogLevel", list(logging._nameToLevel.keys()))
+
+class LogLevel(StrEnum):
+    DEBUG = auto()
+    INFO = auto()
+    WARNING = auto()
+    ERROR = auto()
 
 
 def main():
@@ -19,23 +24,18 @@ def cli(
         "./",
         envvar="SOURCE_REPO",
     ),
-    output_dir: Optional[str] = typer.Argument("./www", envvar="OUTPUT_DIR"),
-    clone_dir: Optional[str] = typer.Option(
-        None,
-        envvar="CLONE_DIR",
-    ),
+    output_dir: str = typer.Argument("./www", envvar="OUTPUT_DIR"),
+    clone_dir: Optional[str] = typer.Option(None, envvar="CLONE_DIR"),
     repo_subdir: str = typer.Option("", envvar="REPO_SUBDIR"),
-    fetch: Optional[bool] = typer.Option(False, envvar="FETCH"),
-    loglevel: Optional[LogLevel] = typer.Option(
+    fetch: bool = typer.Option(False, envvar="FETCH"),
+    loglevel: LogLevel = typer.Option(
         LogLevel.INFO, "--loglevel", "-l", envvar="LOG_LEVEL"
     ),
 ):
     logging.basicConfig(level=loglevel.upper(), format="%(message)s")
     logging.info(f"Generating blog into '{output_dir}'...")
-    with GitBlog(source_repo, clone_dir, str(repo_subdir), fetch=fetch) as gb:
-        gb.write_articles(output_dir)
-        gb.write_indexes(output_dir)
-        gb.copy_static_assets(output_dir)
+    with GitBlog(source_repo, clone_dir, repo_subdir, fetch=fetch) as gb:
+        gb.write_blog(output_dir)
     logging.info("Done.")
 
 
